
#include "common.h"

#include <project.h>

uint8 ledOnFlag = 0;
char flag=0;
uint32  startTime,period;
uint16 t_on_delay,t_off_delay, no_of_cycles;

/*******************************************************************************
* Function Name: StackEventHandler
*******************************************************************************/
void StackEventHandler(uint32 event, void *eventParam)
{
        
    switch(event)
    {
        
        case CYBLE_EVT_STACK_ON:
        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED:
            CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
            Advertising_LED_Write(LED_ON);
            Alert_LED_Write(LED_OFF);
            break;
        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
            Advertising_LED_Write(LED_OFF);
            Disconnect_LED_Write(LED_OFF);
            //Timer is started
             Timer_Start();
			  flag=0;
            break;
        case CYBLE_EVT_GAPP_ADVERTISEMENT_START_STOP:
            if(CyBle_GetState() == CYBLE_STATE_DISCONNECTED)
            {             
                Advertising_LED_Write(LED_OFF);
                Disconnect_LED_Write(LED_ON);
                CySysPmSetWakeupPolarity(CY_PM_STOP_WAKEUP_ACTIVE_HIGH);
                CySysPmStop();    
            }
            break;        
        case CYBLE_EVT_GATTS_WRITE_REQ:
              
            break;
        
        /* Other events that are generated by the BLE Component that
         * are not required for functioning of this design */
        /**********************************************************
        *                       General Events
        ***********************************************************/
        case CYBLE_EVT_HARDWARE_ERROR:    /* This event indicates that some internal HW error has occurred. */
            break;

        case CYBLE_EVT_HCI_STATUS:
            break;

        /**********************************************************
        *                       GAP Events
        ***********************************************************/
        case CYBLE_EVT_GAP_AUTH_REQ:
            break;

        case CYBLE_EVT_GAP_PASSKEY_ENTRY_REQUEST:
            break;

        case CYBLE_EVT_GAP_PASSKEY_DISPLAY_REQUEST:
            break;

        case CYBLE_EVT_GAP_AUTH_COMPLETE:

            break;
        case CYBLE_EVT_GAP_AUTH_FAILED:

            break;

        case CYBLE_EVT_GAP_ENCRYPT_CHANGE:
            break;

        case CYBLE_EVT_GAPC_CONNECTION_UPDATE_COMPLETE:
            break;

        /**********************************************************
        *                       GATT Events
        ***********************************************************/
        case CYBLE_EVT_GATT_CONNECT_IND:
            break;

        case CYBLE_EVT_GATT_DISCONNECT_IND:
            break;

        case CYBLE_EVT_GATTS_XCNHG_MTU_REQ:
            break;

        case CYBLE_EVT_GATTS_READ_CHAR_VAL_ACCESS_REQ:
            break;

        /**********************************************************
        *                       Other Events
        ***********************************************************/
        case CYBLE_EVT_PENDING_FLASH_WRITE:
            break;

        default:
            break;
    }
}

CY_ISR(MY_ISR) {
   flag = 1;
   Timer_ClearInterrupt(Timer_INTR_MASK_TC); 
}


/*******************************************************************************
* Function Name: main
*******************************************************************************/
int main()
{
    CYBLE_API_RESULT_T apiResult;
    
     isr_1_StartEx(MY_ISR);
    CyGlobalIntEnable;
    
    RTC_1_Start();

    apiResult = CyBle_Start(StackEventHandler);

    if(apiResult != CYBLE_ERROR_OK)
    {
        /* BLE stack initialization failed, check your configuration */
        CYASSERT(0);
    }
   
     while(1)
    { 
        
        CYBLE_BLESS_STATE_T blessState;
        uint8 intrStatus;

        /* Single API call to service all the BLE stack events. Must be
         * called at least once in a BLE connection interval */
        CyBle_ProcessEvents();
        
        /* Configure BLESS in Deep-Sleep mode */
        CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);
		
		 /* Update on the blue LED */
        update();
        
	     if(flag) 
		 {
			/* Prevent interrupts while entering system low power modes */
	        intrStatus = CyEnterCriticalSection();
	        
	        /* Get the current state of BLESS block */
	        blessState = CyBle_GetBleSsState();
	        
	        /* If BLESS is in Deep-Sleep mode or the XTAL oscillator is turning on, 
	         * then PSoC 4 BLE can enter Deep-Sleep mode (1.3uA current consumption) */
	        if(blessState == CYBLE_BLESS_STATE_ECO_ON || 
	            blessState == CYBLE_BLESS_STATE_DEEPSLEEP)
	        {
	            CySysPmDeepSleep();
	        }
	        else if(blessState != CYBLE_BLESS_STATE_EVENT_CLOSE)
	        {
	            /* If BLESS is active, then configure PSoC 4 BLE system in 
	             * Sleep mode (~1.6mA current consumption) */
	            CySysPmSleep();
	        }
	        else
	        {
	            /* Keep trying to enter either Sleep or Deep-Sleep mode */    
	        }
	        CyExitCriticalSection(intrStatus);
	            
	      
	    }
	}
}
void update(void)
{    
    
       t_on_delay=1000;
        t_off_delay=1000;
        no_of_cycles=7;
    period=no_of_cycles*(t_on_delay+t_off_delay);
    Timer_WritePeriod(period);
    Timer_Enable();
     
        if(!flag)
		{
	        if(!ledOnFlag && RTC_1_GetUnixTime() - startTime >= t_on_delay)
	        { 
	            Alert_LED_Write(LED_ON);
	            ledOnFlag = 1;
	            startTime = RTC_1_GetUnixTime();
	        }
	        if(ledOnFlag && RTC_1_GetUnixTime() - startTime >=t_off_delay)
	        {
	            Alert_LED_Write(LED_OFF);
	            ledOnFlag = 0;
	            startTime = RTC_1_GetUnixTime();
	            
	        }
	        
	    }	
    
}



/* [] END OF FILE */
